==> libreoffice-fresh-sdk-25.2.3-1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.js <==
var interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager =
[
    [ "XComponent", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a3ee2eab6ea072f036a4548a48b0ed454", null ],
    [ "XModifyBroadcaster", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#ae0517cf0f1a21bce4a114d75e26ba762", null ],
    [ "addExtension", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a1eb6801fc047404af0a52a85a00eb718", null ],
    [ "checkPrerequisitesAndEnable", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a85dae8d1957f673972424d5717121f4f", null ],
    [ "createAbortChannel", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#adbe4b5b8a31808abd5059bfed876779d", null ],
    [ "disableExtension", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a9661c24f9e0c8d40c93b00fbb1bff0e6", null ],
    [ "enableExtension", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a7311719c0ce6c85d2d780c63c2c33e30", null ],
    [ "getAllExtensions", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a62c1f00f82f1f4249f55a800fe2e2d87", null ],
    [ "getDeployedExtension", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#ad427d240f851350209205c1aea7975b3", null ],
    [ "getDeployedExtensions", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a4e6e99f93c1ba583c302bd43c48cdd7f", null ],
    [ "getExtensionsWithSameIdentifier", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#ae233214431b5ce95a3e5d0e9de3a6f57", null ],
    [ "getExtensionsWithUnacceptedLicenses", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a9c9b4769788efa5196f0b586198a7dc4", null ],
    [ "getSupportedPackageTypes", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a1f88ea91ed646a2e07af2ade3c947c47", null ],
    [ "isReadOnlyRepository", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a32fc621ccc82dc4a785562a464cf3465", null ],
    [ "reinstallDeployedExtensions", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#ae691852a2824a35390897c8809cafe87", null ],
    [ "removeExtension", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a19f9547946999c40a9d18535e99cec13", null ],
    [ "synchronize", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#af120e3a283e0c0154a331703f6bc1a35", null ]
];

==> libreoffice-fresh-sdk-25.8.4-1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.js <==
var interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager =
[
    [ "com::sun::star::lang::XComponent", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a3ee2eab6ea072f036a4548a48b0ed454", null ],
    [ "com::sun::star::util::XModifyBroadcaster", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#ae0517cf0f1a21bce4a114d75e26ba762", null ],
    [ "addExtension", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a1eb6801fc047404af0a52a85a00eb718", null ],
    [ "checkPrerequisitesAndEnable", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a85dae8d1957f673972424d5717121f4f", null ],
    [ "createAbortChannel", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#adbe4b5b8a31808abd5059bfed876779d", null ],
    [ "disableExtension", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a9661c24f9e0c8d40c93b00fbb1bff0e6", null ],
    [ "enableExtension", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a7311719c0ce6c85d2d780c63c2c33e30", null ],
    [ "getAllExtensions", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a62c1f00f82f1f4249f55a800fe2e2d87", null ],
    [ "getDeployedExtension", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#ad427d240f851350209205c1aea7975b3", null ],
    [ "getDeployedExtensions", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a4e6e99f93c1ba583c302bd43c48cdd7f", null ],
    [ "getExtensionsWithSameIdentifier", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#ae233214431b5ce95a3e5d0e9de3a6f57", null ],
    [ "getExtensionsWithUnacceptedLicenses", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a9c9b4769788efa5196f0b586198a7dc4", null ],
    [ "getSupportedPackageTypes", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a1f88ea91ed646a2e07af2ade3c947c47", null ],
    [ "isReadOnlyRepository", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a32fc621ccc82dc4a785562a464cf3465", null ],
    [ "reinstallDeployedExtensions", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#ae691852a2824a35390897c8809cafe87", null ],
    [ "removeExtension", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#a19f9547946999c40a9d18535e99cec13", null ],
    [ "synchronize", "interfacecom_1_1sun_1_1star_1_1deployment_1_1XExtensionManager.html#af120e3a283e0c0154a331703f6bc1a35", null ]
];
